@@ -378,19 +378,22 @@ class PharmaSecureNumberRequestProcessStep(rules.Step):
             ns)
         if len(tags) == 0:
             # Error from PharmaSecure
-            er = root.find('*/*/*/a:ErrorCode', ns).text
-            raise Exception("Error from PharmaSecure {0}".format(er))
+            msg = ""
+            try:
+                er = root.find('*/*/*/a:ErrorCode', ns).text
+                msg = "Error from PharmaSecure {0}".format(er)
+            except:
+                msg = 'PharmaSecure returned no Serial Numbers for {0}'.format(region_name)
+                self.error(msg)
+
+            raise Exception(msg)
+
 
         serial_numbers = []
         # add tags to serial_numbers array
         for tag in tags:
             sn = conversion.BarcodeConverter(tag.find('a:SerialNumber', ns).text, company_prefix_length=len("0370010"))
-            if sn.sscc18 is None:
-                nums = sn.epc_urn.split(":")
-                num = "0.{0}".format(nums[4])
-            else:
-                num = sn.sscc18
-
+            num = sn.serial_number
             serial_numbers.append(num)
 
         self.write_list(serial_numbers, region)
@@ -415,6 +418,8 @@ class PharmaSecureNumberRequestProcessStep(rules.Step):
             cursor.execute('insert into %s (serial_number, used) values '
                            '(?, ?)' % get_region_table(region), (id, 0))
         connection.commit()
+        s = ","
+        self.info('Saved Serial Numbers. {0}'.format(s.join(serial_numbers)))
         self.info("Execution time: %.3f seconds." % (time.time() - start))
 
     def get_list_based_region(self, machine_name):
@@ -446,32 +451,3 @@ class PharmaSecureNumberRequestProcessStep(rules.Step):
         return {}
 
 
-class PharmaSecureTemplateStep(TemplateStep):
-
-    def execute(self, data, rule_context: RuleContext):
-        # convert
-        if len(str(data[0])) > 18:
-            # this is an SGTIN, get the TradeItem
-            d = data[0]
-            # remove the leading "0."
-            d = d[2:]
-            # build the urn
-            urn = "urn:epc:id:sgtin:{0}".format(d)
-            # convert the urn to get the gtin14
-            sn = conversion.URNConverter(urn)
-            # Populate the trade_item context value
-            try:
-                rule_context.context['trade_item']= TradeItem.objects.get(
-                    GTIN14=sn.gtin14
-                )
-            except:
-                raise
-        # call super and return
-        return super().execute(data, rule_context)
-
-    def on_failure(self):
-        super().on_failure()
-
-    @property
-    def declared_parameters(self):
-        return {}
